@@ -42,8 +42,13 @@ def print_version(ctx, param, value):
 
 def configure_logging(loglevel):
     # configure file logger to not clutter stdout with log lines
-    logging.basicConfig(level=loglevel, filename='/tmp/pequod-cli.log',
-                        format='%(asctime)s %(levelname)s %(name)s: %(message)s')
+    for fn in '/tmp/pequod-cli-{}.log'.format(os.getuid()), '/dev/null':
+        try:
+            logging.basicConfig(level=loglevel, filename=fn,
+                                format='%(asctime)s %(levelname)s %(name)s: %(message)s')
+            break
+        except:
+            pass
     logging.getLogger('urllib3.connectionpool').setLevel(logging.WARNING)
     logging.getLogger('requests.packages.urllib3.connectionpool').setLevel(logging.WARNING)
 
