@@ -277,21 +277,47 @@ def add_location(ctx, location_name, ipv4_subnet):
     ok()
 
 
-@manager.command()
-@click.pass_obj
+@manager.group(invoke_without_command=True, cls=AliasedGroup)
+@click.pass_context
 def networks(ctx):
     """
     Show all available networks
     """
-    data = ctx.manager.get('/networks')
-    rows = []
-    for row in data['networks']:
-        row['ipv6_subnet'] = IPNetwork('{}/{}'.format(row['ipv6_subnet_ip'], row['ipv6_subnet_prefixlen']))
-        row['ipv6_routes'] = ', '.join([
-            '{destination_ip}/{destination_prefixlen} via {gateway}'.format(**r) for r in row['ipv6_routes']])
-        rows.append(row)
-    rows.sort(key=itemgetter('zone_name'))
-    print_table('zone_name location_name ipv6_subnet ipv6_gateway ipv6_dns ipv6_routes'.split(), rows)
+    if not ctx.invoked_subcommand:
+        ctx = ctx.obj
+        data = ctx.manager.get('/networks')
+        rows = []
+        for row in data['networks']:
+            row['ipv6_subnet'] = IPNetwork('{}/{}'.format(row['ipv6_subnet_ip'], row['ipv6_subnet_prefixlen']))
+            row['ipv6_routes'] = ', '.join([
+                '{destination_ip}/{destination_prefixlen} via {gateway}'.format(**r) for r in row['ipv6_routes']])
+            rows.append(row)
+        rows.sort(key=itemgetter('zone_name'))
+        print_table('zone_name location_name ipv6_subnet ipv6_gateway ipv6_dns ipv6_routes'.split(), rows)
+
+
+@networks.command('add')
+@click.argument('zone_name')
+@click.argument('location_name')
+@click.argument('ipv6_subnet')
+@click.argument('ipv6_gateway')
+@click.option('--ipv6-dns', help='Use specific nameserver')
+@click.pass_obj
+def add_network(ctx, zone_name, location_name, ipv6_subnet, ipv6_gateway, ipv6_dns):
+    """
+    Add a new network
+    """
+    ipv6_subnet_ip, ipv6_subnet_prefixlen = ipv6_subnet.split('/')
+    ipv6_subnet_prefixlen = int(ipv6_subnet_prefixlen)
+    data = {
+        'ipv6_subnet_ip': ipv6_subnet_ip,
+        'ipv6_subnet_prefixlen': ipv6_subnet_prefixlen,
+        'ipv6_gateway': ipv6_gateway,
+        'ipv6_dns': ipv6_dns
+    }
+    action('Adding network for zone {zone_name} and location {location_name} with subnet {ipv6_subnet}..', **vars())
+    ctx.manager.put('/networks/{}/{}'.format(location_name, zone_name), data=data)
+    ok()
 
 
 @manager.group('external-services', invoke_without_command=True, cls=AliasedGroup)
